/*
 * Export the framebuffer as a data space accessible via the "fb" capability.
 *
 * Copyright (C) 2018, 2023 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include "fb-lcd.h"
#include "fb-lcd-run.h"
#include "fb-run.h"



int fb_lcd_run()
{
  /* Obtain the LCD device. */

  Lcd_device *lcd_device = Lcd_device::get_device();

  /* Memory allocation capability for the framebuffer data. */

  l4re_ds_t mem = lcd_device->get_framebuffer_cap();

  if (l4_is_invalid_cap(mem))
    return 1;

  /* Enable the LCD device. */

  lcd_device->enable();

  /* Initialise and register a server object. */

  Framebuffer_lcd_server obj(mem, lcd_device);

  return run(&obj);
}
